Application Models
==================

We demonstrate MobsPy with several examples, primarily from synthetic biology.

AB_2CD
------
.. literalinclude:: example_models/application_models/AB_2CD.py

For_The_Trees
-------------
.. literalinclude:: example_models/application_models/For_The_Trees.py

AND_gate
--------
.. literalinclude:: example_models/application_models/AND_gate.py

NOR_gate
--------
.. literalinclude:: example_models/application_models/NOR_gate.py

CRISPR_Oscillator
-----------------
.. literalinclude:: example_models/application_models/CRISPR_Oscillator.py

donor_receptor
--------------
.. literalinclude:: example_models/application_models/donor_receptor.py

oscillator
----------
.. literalinclude:: example_models/application_models/oscillator.py

positive_phage_feedback_loop
----------------------------
.. literalinclude:: example_models/application_models/positive_phage_feedback_loop.py

random_walk
-----------
.. literalinclude:: example_models/application_models/random_walk.py

simple_infection
----------------
.. literalinclude:: example_models/application_models/simple_infection.py

simple_repressor
----------------
.. literalinclude:: example_models/application_models/simple_repressor.py

simple_rule_based_and_gate
--------------------------
.. literalinclude:: example_models/application_models/simple_rule_based_and_gate.py